Index: /trunk/wp-content/plugins/xpressme/xpressme.php
===================================================================
--- /trunk/wp-content/plugins/xpressme/xpressme.php	(revision 77)
+++ /trunk/wp-content/plugins/xpressme/xpressme.php	(revision 78)
@@ -17,5 +17,5 @@
 
 $XPressME = new XPressME_Class();
-if (!is_admin_page_call()){
+if (is_xpress_index_page_call()){
 	require_once dirname( __FILE__ ).'/include/pluggable-override.php' ;
 }

Index: /trunk/include/oninstall.php
===================================================================
--- /trunk/include/oninstall.php	(revision 77)
+++ /trunk/include/oninstall.php	(revision 78)
@@ -75,5 +75,5 @@
 //	update_option('upload_path', $module->getVar("dirname"));
 	
 	/* activate the tag plugin */
 	$plugin_current = "xpressme/xpressme.php";
 	update_option('active_plugins', array($plugin_current));
@@ -85,6 +85,7 @@
 	$wpdb->query("ALTER TABLE $wpdb->posts CHANGE `post_author` `post_author` mediumint(8) NOT NULL DEFAULT '0'");
 	$ID = is_object($GLOBALS["xoopsUser"])?$GLOBALS["xoopsUser"]->getVar("uid"):1;
-   	require_once($mydirpath . '/include/user_sync.php');
-	xpress_user_sync($ID);
+//   	require_once($mydirpath . '/include/user_sync.php');
+	$sync_messg = '';
+	xpress_user_sync($ID,$sync_messg);		//this function in XPressME plugin 
 
 	// Set Default data
@@ -75,5 +75,5 @@
 //	update_option('upload_path', $module->getVar("dirname"));
 	
-	/* activate the tag plugin */
+	/* activate the XPressME plugin */
 	$plugin_current = "xpressme/xpressme.php";
 	update_option('active_plugins', array($plugin_current));